==> haskell-regex-compat-tdfa-0.95.1.4-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat-tdfa
version: 0.95.1.4
id: regex-compat-tdfa-0.95.1.4-GTUYGjeBdPeCza14JyNUWb
key: regex-compat-tdfa-0.95.1.4-GTUYGjeBdPeCza14JyNUWb
license: BSD3
copyright: Copyright (c) Christopher Kuklewicz 2006
           (c) shelarcy 2012
maintainer: shelarcy <shelarcy@gmail.com>
stability: Seems to work, passes a few tests
homepage: http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url: http://hackage.haskell.org/package/regex-compat-tdfa
synopsis: Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.
    .
    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.
    .
    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Text.Regex
abi: 362caa7fc396afad468434e9c518b835
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-compat-tdfa-0.95.1.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/regex-compat-tdfa-0.95.1.4
hs-libraries: HSregex-compat-tdfa-0.95.1.4-GTUYGjeBdPeCza14JyNUWb
depends:
    array-0.5.2.0 base-4.10.1.0
    regex-base-0.93.2-2WymZ6oErYqGB0H6LBWVXT
    regex-tdfa-1.2.3-48vhRVRi5RgG8cWcKB3lmL
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             regex-base-0.93.2-2WymZ6oErYqGB0H6LBWVXT=00b0a18913cb065ba60dd774df7963ef
             regex-tdfa-1.2.3-48vhRVRi5RgG8cWcKB3lmL=a02f2fe5079dfc41cf29eeb9a27bc378
haddock-interfaces: /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-tdfa-0.95.1.4-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-compat-tdfa
version: 0.95.1.4
id: regex-compat-tdfa-0.95.1.4-6NeOxaXyKetCHMsVAbDwwF
key: regex-compat-tdfa-0.95.1.4-6NeOxaXyKetCHMsVAbDwwF
license: BSD-3-Clause
copyright: Copyright (c) Christopher Kuklewicz 2006
           (c) shelarcy 2012
maintainer: shelarcy <shelarcy@gmail.com>
author: Christopher Kuklewicz
stability: Seems to work, passes a few tests
homepage: http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url: http://hackage.haskell.org/package/regex-compat-tdfa
synopsis: Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.
    .
    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.
    .
    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.
category: Text
abi: a7c295ba44c7568552113855bf206177
exposed: True
exposed-modules:
    Text.Regex
import-dirs: /usr/lib/ghc-8.4.2/site-local/regex-compat-tdfa-0.95.1.4
library-dirs: /usr/lib/ghc-8.4.2/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/regex-compat-tdfa-0.95.1.4
hs-libraries: HSregex-compat-tdfa-0.95.1.4-6NeOxaXyKetCHMsVAbDwwF
depends:
    array-0.5.2.0 base-4.11.1.0
    regex-base-0.93.2-98bD2PeVUkV8MO804tnXmq
    regex-tdfa-1.2.3-1e6W0u5rRmsDEmJafeJHae
abi-depends: array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             regex-base-0.93.2-98bD2PeVUkV8MO804tnXmq=cd319b2feffbc522d3044f7e8d9cb6d7
             regex-tdfa-1.2.3-1e6W0u5rRmsDEmJafeJHae=0f757e6977aca47897bf4bd5e919fe11
haddock-interfaces: /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
